#[repr(C)]pub struct SKOverlayAppClipConfiguration { /* private fields */ }Available on crate feature
SKOverlayConfiguration only.Implementations
sourceimpl SKOverlayAppClipConfiguration
impl SKOverlayAppClipConfiguration
pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>
pub unsafe fn new() -> Retained<Self>
pub unsafe fn initWithPosition( this: Allocated<Self>, position: SKOverlayPosition ) -> Retained<Self>
pub unsafe fn campaignToken(&self) -> Option<Retained<NSString>>
pub unsafe fn setCampaignToken(&self, campaign_token: Option<&NSString>)
pub unsafe fn providerToken(&self) -> Option<Retained<NSString>>
pub unsafe fn setProviderToken(&self, provider_token: Option<&NSString>)
pub unsafe fn customProductPageIdentifier(&self) -> Option<Retained<NSString>>
pub unsafe fn setCustomProductPageIdentifier( &self, custom_product_page_identifier: Option<&NSString> )
pub unsafe fn latestReleaseID(&self) -> Option<Retained<NSString>>
pub unsafe fn setLatestReleaseID(&self, latest_release_id: Option<&NSString>)
pub unsafe fn position(&self) -> SKOverlayPosition
pub unsafe fn setPosition(&self, position: SKOverlayPosition)
pub unsafe fn setAdditionalValue_forKey( &self, value: Option<&AnyObject>, key: &NSString )
pub unsafe fn additionalValueForKey( &self, key: &NSString ) -> Option<Retained<AnyObject>>
Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.