Struct objc2_store_kit::SKPayment
source · #[repr(C)]pub struct SKPayment { /* private fields */ }Available on crate feature
SKPayment only.Implementations
sourceimpl SKPayment
impl SKPayment
pub unsafe fn paymentWithProduct(product: &SKProduct) -> Retained<Self>
Available on crate feature
SKProduct only.pub unsafe fn paymentWithProductIdentifier( identifier: &NSString ) -> Retained<AnyObject>
👎Deprecated
pub unsafe fn productIdentifier(&self) -> Retained<NSString>
pub unsafe fn requestData(&self) -> Option<Retained<NSData>>
pub unsafe fn quantity(&self) -> NSInteger
pub unsafe fn applicationUsername(&self) -> Option<Retained<NSString>>
pub unsafe fn simulatesAskToBuyInSandbox(&self) -> bool
pub unsafe fn paymentDiscount(&self) -> Option<Retained<SKPaymentDiscount>>
Available on crate feature
SKPaymentDiscount only.Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.