Struct objc2_store_kit::SKProduct
source · #[repr(C)]pub struct SKProduct { /* private fields */ }Available on crate feature
SKProduct only.Implementations
sourceimpl SKProduct
impl SKProduct
pub unsafe fn localizedDescription(&self) -> Retained<NSString>
pub unsafe fn localizedTitle(&self) -> Retained<NSString>
pub unsafe fn price(&self) -> Retained<NSDecimalNumber>
pub unsafe fn priceLocale(&self) -> Retained<NSLocale>
pub unsafe fn productIdentifier(&self) -> Retained<NSString>
pub unsafe fn isDownloadable(&self) -> bool
pub unsafe fn downloadable(&self) -> bool
👎Deprecated
pub unsafe fn contentLengths(&self) -> Retained<NSArray<NSNumber>>
👎Deprecated
pub unsafe fn downloadContentLengths(&self) -> Retained<NSArray<NSNumber>>
pub unsafe fn contentVersion(&self) -> Retained<NSString>
👎Deprecated
pub unsafe fn downloadContentVersion(&self) -> Retained<NSString>
pub unsafe fn subscriptionPeriod( &self ) -> Option<Retained<SKProductSubscriptionPeriod>>
pub unsafe fn introductoryPrice(&self) -> Option<Retained<SKProductDiscount>>
Available on crate feature
SKProductDiscount only.pub unsafe fn subscriptionGroupIdentifier(&self) -> Option<Retained<NSString>>
pub unsafe fn discounts(&self) -> Retained<NSArray<SKProductDiscount>>
Available on crate feature
SKProductDiscount only.Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.